==> haskell-regex-applicative-text-0.1.0.1-282-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-8KwMfEJ28rv2zrleOIeyTY
key:                  regex-applicative-text-0.1.0.1-8KwMfEJ28rv2zrleOIeyTY
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  ad05aed539f61e5e4d646e2cfbad8823
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-8KwMfEJ28rv2zrleOIeyTY
depends:
    base-4.17.2.1 regex-applicative-0.3.4-AEYhPtWjuOqD9r5qS34Pyq
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-283-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-FCyVrQr1cpyB738bERBcN1
key:                  regex-applicative-text-0.1.0.1-FCyVrQr1cpyB738bERBcN1
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  e9c6e8214f7d82b1b69bed86049451ed
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-FCyVrQr1cpyB738bERBcN1
depends:
    base-4.17.2.1 regex-applicative-0.3.4-As41WZZJGWB37sAVKtx0xj
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
